#Replication Code for Brian Palmer-Rubin, Candelaria Garay, and Mathias Poertner, "Incentives for Organizational Participation: A Recruitment Experiment in Mexico," Comparative Political Studies

#Analysis conducted in R version 3.6.0

#install the following packages
library(plyr)
library(ggplot2)
library(cowplot)

#Set working directory in the following line:
setwd("~/Replication_materialsCPS")

load("repdat.RData")

names(repdat)
dim(repdat)

data<-repdat

########## Table 1: Overall Findings

data.treat<-data[data$flier!="control"&!is.na(data$flier),]
data.control<-data[data$flier=="control"&!is.na(data$flier),]

# Recruit.dum

cdata <- ddply(data.treat, "flier", summarise,
               N    = length(recruit.dum),
               N.control = sum(!is.na(data.control$recruit.dum)),
               mean = mean(recruit.dum,na.rm=T),
               sd.treat   = sd(recruit.dum,na.rm=T),
               sd.control = sd(data.control$recruit.dum,na.rm=T),
               effect = mean(recruit.dum,na.rm=T)-mean(data.control$recruit.dum,na.rm=T),
               se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / sum(!is.na(data.control$recruit.dum)))),
               t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
               p.value=pt(t.value,length(recruit.dum)+sum(!is.na(data.control$recruit.dum))-2,lower.tail=F)
)
cdata

mean(data.control$recruit.dum,na.rm=T)

# phone.recruit

cdata.phone <- ddply(data.treat, "flier", summarise,
                     N    = sum(!is.na(phone.recruit)),
                     N.control = sum(!is.na(data.control$phone.recruit)),
                     mean = mean(phone.recruit,na.rm=T),
                     sd.treat   = sd(phone.recruit,na.rm=T),
                     sd.control = sd(data.control$phone.recruit,na.rm=T),
                     effect = mean(phone.recruit,na.rm=T)-mean(data.control$phone.recruit,na.rm=T),
                     se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / sum(!is.na(data.control$phone.recruit)))),
                     t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                     p.value=pt(t.value,length(phone.recruit)+N.control-2,lower.tail=F)
)
cdata.phone

mean(data.control$phone.recruit,na.rm=T)
sum(!is.na(data$phone.recruit))

########## Table 2: Members vs. Non-Members

org.membs<-data[data$org_mem2==1&!is.na(data$org_mem2),]
non.membs<-data[data$org_mem2==0&!is.na(data$org_mem2),]

org.membs.treat<-org.membs[org.membs$flier!="control"&!is.na(org.membs$flier),]
org.membs.control<-org.membs[org.membs$flier=="control",]

non.membs.treat<-non.membs[non.membs$flier!="control"&!is.na(non.membs$flier),]
non.membs.control<-non.membs[non.membs$flier=="control",]

# Members

cdata.memb.phone <- ddply(org.membs.treat, "flier", summarise,
                          N    = sum(!is.na(phone.recruit)),
                          N.control = sum(!is.na(org.membs.control$phone.recruit)),
                          mean = mean(phone.recruit,na.rm=T),
                          sd.treat   = sd(phone.recruit,na.rm=T),
                          sd.control = sd(org.membs.control$phone.recruit,na.rm=T),
                          effect = mean(phone.recruit,na.rm=T)-mean(org.membs.control$phone.recruit,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb.phone

mean(org.membs.control$phone.recruit)

# Non-Members

cdata.nonmemb.phone <- ddply(non.membs.treat, "flier", summarise,
                             N    = sum(!is.na(phone.recruit)),
                             N.control = sum(!is.na(non.membs.control$phone.recruit)),
                             mean = mean(phone.recruit,na.rm=T),
                             sd.treat   = sd(phone.recruit,na.rm=T),
                             sd.control = sd(non.membs.control$phone.recruit,na.rm=T),
                             effect = mean(phone.recruit,na.rm=T)-mean(non.membs.control$phone.recruit,na.rm=T),
                             se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                             t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                             p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb.phone

mean(non.membs.control$phone.recruit)


########## Figure 3: Members vs. Non-Members

cdata.memb.phone$group<-"Member"
cdata.nonmemb.phone$group<-"Non-Member"

cdata.tot<-rbind(cdata.memb.phone,cdata.nonmemb.phone)

cdata.tot$group<-factor(cdata.tot$group,levels=c("Member","Non-Member"))

cdata.tot$flier[cdata.tot$flier=="gestion"]<-"Subsidies"
cdata.tot$flier[cdata.tot$flier=="public"]<-"Public Goods"
cdata.tot$flier[cdata.tot$flier=="services"]<-"Services"
cdata.tot$flier[cdata.tot$flier=="pressure"]<-"Peer Esteem"

cdata.tot$flier<-factor(cdata.tot$flier,levels=c("Subsidies","Public Goods","Services","Peer Esteem"))
names(cdata.tot)[1]<-paste("Treatment")
names(cdata.tot)[7]<-paste("Effect")

pdf(file="fig3.pdf",width=8,height=6)

ggplot(cdata.tot, aes(x=Treatment, y = Effect, group = Treatment)) +
  #draws the means
  geom_point() +
  #draws the CI error bars
  geom_errorbar(data=cdata.tot, aes(ymin=Effect-1.28*se.effect, ymax=Effect+1.28*se.effect), width=.1) + geom_hline(yintercept=0, linetype="dashed", color = "red") + theme(legend.position="none") + theme(text = element_text(size=20), axis.text.x = element_text(angle = 60, hjust = 1)) +
  facet_grid(~group) +ylab(label="Conditional Average Treatment Effect") 

dev.off()

########## Table 3: Low-Income vs. High-Income by Membership


hi.inc<-data[data$income2=="high",]
hi.inc<-hi.inc[!is.na(hi.inc$income2),]

lo.inc<-data[data$income2=="low",]
lo.inc<-lo.inc[!is.na(lo.inc$income2),]

lo.inc.treat<-lo.inc[lo.inc$flier!="control",]
lo.inc.control<-lo.inc[lo.inc$flier=="control",]

hi.inc.treat<-hi.inc[hi.inc$flier!="control",]
hi.inc.control<-hi.inc[hi.inc$flier=="control",]

lo.inc.memb<-lo.inc[lo.inc$org_mem2==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem2),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem2==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem2),]

hi.inc.memb<-hi.inc[hi.inc$org_mem2==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem2),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem2==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem2),]

# Low-Income Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

dim(lo.inc.memb.treat)
dim(lo.inc.memb.control)

aggregate(c(lo.inc.memb$phone.recruit), list(lo.inc.memb$flier), mean,na.rm=T)

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

# Low-Income Non-members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

# High-Income Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone


# High-Income Non-members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

dim(hi.inc.nomemb.treat)
dim(hi.inc.nomemb.control)

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit,na.rm=T)

# N's

sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Table 4: Distinct Types of Organization Members

# Create datasets for each group of organization members
union.membs<-data[data$memb.union2==1&!is.na(data$memb.union2),]
camp.membs<-data[data$memb.camp2==1&!is.na(data$memb.camp2),]
neigh.membs<-data[data$memb.neigh2==1&!is.na(data$memb.neigh2),]
bus.membs<-data[data$memb.bus2==1&!is.na(data$memb.bus2),]

# Union Members

union.membs.treat<-union.membs[union.membs$flier!="control",]
union.membs.control<-union.membs[union.membs$flier=="control",]

cdata.union.phone <- ddply(union.membs.treat, "flier", summarise,
                           N    = sum(!is.na(phone.recruit)),
                           N.control = sum(!is.na(union.membs.control$phone.recruit)),
                           mean = mean(phone.recruit,na.rm=T),
                           sd.treat   = sd(phone.recruit,na.rm=T),
                           sd.control = sd(union.membs.control$phone.recruit,na.rm=T),
                           effect = mean(phone.recruit,na.rm=T)-mean(union.membs.control$phone.recruit,na.rm=T),
                           se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                           t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                           p.value=pt(t.value,N+N.control-2,lower.tail=T)
)
cdata.union.phone

mean(union.membs.control$phone.recruit,na.rm=T)

# Peasant Assoc. Members

camp.membs.treat<-camp.membs[camp.membs$flier!="control",]
camp.membs.control<-camp.membs[camp.membs$flier=="control",]

cdata.camp.phone <- ddply(camp.membs.treat, "flier", summarise,
                          N    = sum(!is.na(phone.recruit)),
                          N.control = sum(!is.na(camp.membs.control$phone.recruit)),
                          mean = mean(phone.recruit,na.rm=T),
                          sd.treat   = sd(phone.recruit,na.rm=T),
                          sd.control = sd(camp.membs.control$phone.recruit,na.rm=T),
                          effect = mean(phone.recruit,na.rm=T)-mean(camp.membs.control$phone.recruit,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.camp.phone

mean(camp.membs.control$phone.recruit,na.rm=T)

# Neighborhood Assoc. Members

neigh.membs.treat<-neigh.membs[neigh.membs$flier!="control",]
neigh.membs.control<-neigh.membs[neigh.membs$flier=="control",]

cdata.neigh.phone <- ddply(neigh.membs.treat, "flier", summarise,
                           N    = sum(!is.na(phone.recruit)),
                           N.control = sum(!is.na(neigh.membs.control$phone.recruit)),
                           mean = mean(phone.recruit,na.rm=T),
                           sd.treat   = sd(phone.recruit,na.rm=T),
                           sd.control = sd(neigh.membs.control$phone.recruit,na.rm=T),
                           effect = mean(phone.recruit,na.rm=T)-mean(neigh.membs.control$phone.recruit,na.rm=T),
                           se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                           t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                           p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.neigh.phone

mean(neigh.membs.control$phone.recruit,na.rm=T)

# Business Assoc. Members

bus.membs.treat<-bus.membs[bus.membs$flier!="control",]
bus.membs.control<-bus.membs[bus.membs$flier=="control",]


cdata.bus.phone <- ddply(bus.membs.treat, "flier", summarise,
                         N    = sum(!is.na(phone.recruit)),
                         N.control = sum(!is.na(bus.membs.control$phone.recruit)),
                         mean = mean(phone.recruit,na.rm=T),
                         sd.treat   = sd(phone.recruit,na.rm=T),
                         sd.control = sd(bus.membs.control$phone.recruit,na.rm=T),
                         effect = mean(phone.recruit,na.rm=T)-mean(bus.membs.control$phone.recruit,na.rm=T),
                         se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                         t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                         p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.bus.phone

mean(bus.membs.control$phone.recruit,na.rm=T)

# N's

sum(!is.na(union.membs$phone.recruit))
sum(!is.na(camp.membs$phone.recruit))
sum(!is.na(neigh.membs$phone.recruit))
sum(!is.na(bus.membs$phone.recruit))


########## Table 5: Comparing Members and Non-Members on Covariates

# Female
t.test(org.membs$female,non.membs$female,conf.level=.95,alternative="two.sided")

# Age
t.test(org.membs$A1,non.membs$A1,conf.level=.95,alternative="two.sided")

# Rural
t.test(org.membs$rural50K,non.membs$rural50K,conf.level=.95,alternative="two.sided")

# Income
t.test(org.membs$income,non.membs$income,conf.level=.95,alternative="two.sided")

# Education
t.test(org.membs$ed,non.membs$ed,conf.level=.95,alternative="two.sided")

# Informal Sector
t.test(org.membs$employed.informal,non.membs$employed.informal,conf.level=.95,alternative="two.sided")

# Protest/Rally Participation
t.test(org.membs$manifest,non.membs$manifest,conf.level=.95,alternative="two.sided")

# Voted in 2015
t.test(org.membs$voted.2015,non.membs$voted.2015,conf.level=.95,alternative="two.sided")

# Partisan
t.test(org.membs$partisan,non.membs$partisan,conf.level=.95,alternative="two.sided")

# PRI Partisan
t.test(org.membs$PRI.dum,non.membs$PRI.dum,conf.level=.95,alternative="two.sided")

# Beneficiary
t.test(org.membs$ben.dum,non.membs$ben.dum,conf.level=.95,alternative="two.sided")

# Clientelism
t.test(org.membs$client,non.membs$client,conf.level=.95,alternative="two.sided")


################################################################################
################################################################################
########## Appendix

########## Appendix Table 1: Members vs. Non-Members (Declared Interest Measure)

# Members

cdata.memb <- ddply(org.membs.treat, "flier", summarise,
                          N    = sum(!is.na(recruit.dum)),
                          N.control = sum(!is.na(org.membs.control$recruit.dum)),
                          mean = mean(recruit.dum,na.rm=T),
                          sd.treat   = sd(recruit.dum,na.rm=T),
                          sd.control = sd(org.membs.control$recruit.dum,na.rm=T),
                          effect = mean(recruit.dum,na.rm=T)-mean(org.membs.control$recruit.dum,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb

mean(org.membs.control$recruit.dum,na.rm=T)

# Non-Members

cdata.nonmemb <- ddply(non.membs.treat, "flier", summarise,
                             N    = sum(!is.na(recruit.dum)),
                             N.control = sum(!is.na(non.membs.control$recruit.dum)),
                             mean = mean(recruit.dum,na.rm=T),
                             sd.treat   = sd(recruit.dum,na.rm=T),
                             sd.control = sd(non.membs.control$recruit.dum,na.rm=T),
                             effect = mean(recruit.dum,na.rm=T)-mean(non.membs.control$recruit.dum,na.rm=T),
                             se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                             t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                             p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb

mean(non.membs.control$recruit.dum,na.rm=T)

########## Appendix Figure 1: Members vs. Non-Members (Declared Interest Measure)

cdata.memb$group<-"Member"
cdata.nonmemb$group<-"Non-Member"

cdata.tot<-rbind(cdata.memb,cdata.nonmemb)

cdata.tot$group<-factor(cdata.tot$group,levels=c("Member","Non-Member"))

cdata.tot$flier[cdata.tot$flier=="gestion"]<-"Subsidies"
cdata.tot$flier[cdata.tot$flier=="public"]<-"Public Goods"
cdata.tot$flier[cdata.tot$flier=="services"]<-"Services"
cdata.tot$flier[cdata.tot$flier=="pressure"]<-"Peer Esteem"


cdata.tot$flier<-factor(cdata.tot$flier,levels=c("Subsidies","Public Goods","Services","Peer Esteem"))
names(cdata.tot)[1]<-paste("Treatment")
names(cdata.tot)[7]<-paste("Effect")

pdf(file="AppenFig1.pdf",width=8,height=6)

ggplot(cdata.tot, aes(x=Treatment, y = Effect, group = Treatment)) +
  #draws the means
  geom_point() +
  #draws the CI error bars
  geom_errorbar(data=cdata.tot, aes(ymin=Effect-1.28*se.effect, ymax=Effect+1.28*se.effect), width=.1) + geom_hline(yintercept=0, linetype="dashed", color = "red") + theme(legend.position="none") + theme(text = element_text(size=20), axis.text.x = element_text(angle = 60, hjust = 1)) +
  facet_grid(~group) +ylab(label="Conditional Average Treatment Effect") 

dev.off()


########## Appendix Table 2: Low-Income vs. High-Income by Membership (Declared Interest Measure)

# Lo-Income Members

cdata.loinc.memb <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(recruit.dum)),
                                N.control = sum(!is.na(lo.inc.memb.control$recruit.dum)),
                                mean = mean(recruit.dum,na.rm=T),
                                sd.treat   = sd(recruit.dum,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$recruit.dum,na.rm=T),
                                effect = mean(recruit.dum,na.rm=T)-mean(lo.inc.memb.control$recruit.dum,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb

mean(lo.inc.memb.control$recruit.dum,na.rm=T)

# Low-Income Non-Members

cdata.loinc.nomemb <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(recruit.dum)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$recruit.dum)),
                                  mean = mean(recruit.dum,na.rm=T),
                                  sd.treat   = sd(recruit.dum,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$recruit.dum,na.rm=T),
                                  effect = mean(recruit.dum,na.rm=T)-mean(lo.inc.nomemb.control$recruit.dum,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb

mean(lo.inc.nomemb.control$recruit.dum,na.rm=T)

# High-Income Members

cdata.hiinc.memb <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(recruit.dum)),
                                N.control = sum(!is.na(hi.inc.memb.control$recruit.dum)),
                                mean = mean(recruit.dum,na.rm=T),
                                sd.treat   = sd(recruit.dum,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$recruit.dum,na.rm=T),
                                effect = mean(recruit.dum,na.rm=T)-mean(hi.inc.memb.control$recruit.dum,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb

mean(hi.inc.memb.control$recruit.dum,na.rm=T)

# High-Income Non-Members

cdata.hiinc.nomemb <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(recruit.dum)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$recruit.dum)),
                                  mean = mean(recruit.dum,na.rm=T),
                                  sd.treat   = sd(recruit.dum,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$recruit.dum,na.rm=T),
                                  effect = mean(recruit.dum,na.rm=T)-mean(hi.inc.nomemb.control$recruit.dum,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb

mean(hi.inc.nomemb.control$recruit.dum,na.rm=T)

# Controls: 
aggregate(c(lo.inc.memb$recruit.dum), list(lo.inc.memb$flier), mean,na.rm=T)
aggregate(c(lo.inc.nomemb$recruit.dum), list(lo.inc.nomemb$flier), mean,na.rm=T)
aggregate(c(hi.inc.memb$recruit.dum), list(hi.inc.memb$flier), mean,na.rm=T)
aggregate(c(hi.inc.nomemb$recruit.dum), list(hi.inc.nomemb$flier), mean,na.rm=T)

# N's

sum(!is.na(lo.inc.memb$recruit.dum))
sum(!is.na(lo.inc.nomemb$recruit.dum))
sum(!is.na(hi.inc.memb$recruit.dum))
sum(!is.na(hi.inc.nomemb$recruit.dum))

########## Appendix Table 3: Distinct Types of Organization Members (Declared Interest Measure)

# Union Members

cdata.union.phone <- ddply(union.membs.treat, "flier", summarise,
                           N    = sum(!is.na(recruit.dum)),
                           N.control = sum(!is.na(union.membs.control$recruit.dum)),
                           mean = mean(recruit.dum,na.rm=T),
                           sd.treat   = sd(recruit.dum,na.rm=T),
                           sd.control = sd(union.membs.control$recruit.dum,na.rm=T),
                           effect = mean(recruit.dum,na.rm=T)-mean(union.membs.control$recruit.dum,na.rm=T),
                           se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                           t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                           p.value=pt(t.value,N+N.control-2,lower.tail=T)
)
cdata.union.phone

mean(union.membs.control$recruit.dum,na.rm=T)

# Peasant Assoc. Members

cdata.camp.phone <- ddply(camp.membs.treat, "flier", summarise,
                          N    = sum(!is.na(recruit.dum)),
                          N.control = sum(!is.na(camp.membs.control$recruit.dum)),
                          mean = mean(recruit.dum,na.rm=T),
                          sd.treat   = sd(recruit.dum,na.rm=T),
                          sd.control = sd(camp.membs.control$recruit.dum,na.rm=T),
                          effect = mean(recruit.dum,na.rm=T)-mean(camp.membs.control$recruit.dum,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.camp.phone

mean(camp.membs.control$recruit.dum,na.rm=T)

# Neighborhood Assoc. Members

cdata.neigh.phone <- ddply(neigh.membs.treat, "flier", summarise,
                           N    = sum(!is.na(recruit.dum)),
                           N.control = sum(!is.na(neigh.membs.control$recruit.dum)),
                           mean = mean(recruit.dum,na.rm=T),
                           sd.treat   = sd(recruit.dum,na.rm=T),
                           sd.control = sd(neigh.membs.control$recruit.dum,na.rm=T),
                           effect = mean(recruit.dum,na.rm=T)-mean(neigh.membs.control$recruit.dum,na.rm=T),
                           se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                           t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                           p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.neigh.phone

mean(neigh.membs.control$recruit.dum,na.rm=T)

# Business Assoc. Members

cdata.bus.phone <- ddply(bus.membs.treat, "flier", summarise,
                         N    = sum(!is.na(recruit.dum)),
                         N.control = sum(!is.na(bus.membs.control$recruit.dum)),
                         mean = mean(recruit.dum,na.rm=T),
                         sd.treat   = sd(recruit.dum,na.rm=T),
                         sd.control = sd(bus.membs.control$recruit.dum,na.rm=T),
                         effect = mean(recruit.dum,na.rm=T)-mean(bus.membs.control$recruit.dum,na.rm=T),
                         se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                         t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                         p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.bus.phone

mean(bus.membs.control$recruit.dum,na.rm=T)

# N's

sum(!is.na(union.membs$recruit.dum))
sum(!is.na(camp.membs$recruit.dum))
sum(!is.na(neigh.membs$recruit.dum))
sum(!is.na(bus.membs$recruit.dum))


########## Appendix Table 4: Members vs. Non-Members (Only Personal Membership)

org.membs.per<-data[data$org_mem==1&!is.na(data$org_mem),]
non.membs.per<-data[data$org_mem==0&!is.na(data$org_mem),]

org.membs.treat<-org.membs.per[org.membs.per$flier!="control",]
org.membs.control<-org.membs.per[org.membs.per$flier=="control",]

non.membs.treat<-non.membs.per[non.membs.per$flier!="control",]
non.membs.control<-non.membs.per[non.membs.per$flier=="control",]

# Declared Interest, Members

cdata.memb <- ddply(org.membs.treat, "flier", summarise,
                    N    = length(recruit.dum),
                    N.control = sum(!is.na(org.membs.control$recruit.dum)),
                    mean = mean(recruit.dum,na.rm=T),
                    sd.treat   = sd(recruit.dum,na.rm=T),
                    sd.control = sd(org.membs.control$recruit.dum,na.rm=T),
                    effect = mean(recruit.dum,na.rm=T)-mean(org.membs.control$recruit.dum,na.rm=T),
                    se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                    t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                    p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb

mean(org.membs.control$recruit.dum,na.rm=T)

# Declared Interest, Non-Members

cdata.nonmemb <- ddply(non.membs.treat, "flier", summarise,
                       N    = length(recruit.dum),
                       N.control = sum(!is.na(non.membs.control$recruit.dum)),
                       mean = mean(recruit.dum,na.rm=T),
                       sd.treat   = sd(recruit.dum,na.rm=T),
                       sd.control = sd(org.membs.control$recruit.dum,na.rm=T),
                       effect = mean(recruit.dum,na.rm=T)-mean(non.membs.control$recruit.dum,na.rm=T),
                       se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                       t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                       p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb

mean(non.membs.control$recruit.dum,na.rm=T)


# Behavioral Measure, Members

cdata.memb.phone <- ddply(org.membs.treat, "flier", summarise,
                          N    = sum(!is.na(phone.recruit)),
                          N.control = sum(!is.na(org.membs.control$phone.recruit)),
                          mean = mean(phone.recruit,na.rm=T),
                          sd.treat   = sd(phone.recruit,na.rm=T),
                          sd.control = sd(org.membs.control$phone.recruit,na.rm=T),
                          effect = mean(phone.recruit,na.rm=T)-mean(org.membs.control$phone.recruit,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb.phone

mean(org.membs.control$phone.recruit,na.rm=T)

# Behavioral Measure, Non-Members

cdata.nonmemb.phone <- ddply(non.membs.treat, "flier", summarise,
                             N    = sum(!is.na(phone.recruit)),
                             N.control = sum(!is.na(non.membs.control$phone.recruit)),
                             mean = mean(phone.recruit,na.rm=T),
                             sd.treat   = sd(phone.recruit,na.rm=T),
                             sd.control = sd(non.membs.control$phone.recruit,na.rm=T),
                             effect = mean(phone.recruit,na.rm=T)-mean(non.membs.control$phone.recruit,na.rm=T),
                             se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                             t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                             p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb.phone

mean(non.membs.control$phone.recruit,na.rm=T)

########## Appendix Table 5: Low-Income vs. High-Income by Membership (Only Personal Membership)

lo.inc.memb<-lo.inc[lo.inc$org_mem==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem),]

hi.inc.memb<-hi.inc[hi.inc$org_mem==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem),]

# Low-Income Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

aggregate(c(lo.inc.memb$phone.recruit), list(lo.inc.memb$flier), mean,na.rm=T)

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

mean(lo.inc.memb.control$phone.recruit,na.rm=T)

# Low-Income Non-Members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

mean(lo.inc.nomemb.control$phone.recruit,na.rm=T)

# High-Income Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone

mean(hi.inc.memb.control$phone.recruit,na.rm=T)

# High-Income Non-Members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit)

# N's

sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Appendix Table 6: Distinct Types of Organization Members (Only Personal Membership)

union.membs<-data[data$memb.union==1&!is.na(data$memb.union),]
camp.membs<-data[data$memb.camp==1&!is.na(data$memb.camp),]
neigh.membs<-data[data$memb.neigh==1&!is.na(data$memb.neigh),]
bus.membs<-data[data$memb.bus==1&!is.na(data$memb.bus),]

# Union Members

union.membs.treat<-union.membs[union.membs$flier!="control",]
union.membs.control<-union.membs[union.membs$flier=="control",]

cdata.union.phone <- ddply(union.membs.treat, "flier", summarise,
                           N    = sum(!is.na(phone.recruit)),
                           N.control = sum(!is.na(union.membs.control$phone.recruit)),
                           mean = mean(phone.recruit,na.rm=T),
                           sd.treat   = sd(phone.recruit,na.rm=T),
                           sd.control = sd(union.membs.control$phone.recruit,na.rm=T),
                           effect = mean(phone.recruit,na.rm=T)-mean(union.membs.control$phone.recruit,na.rm=T),
                           se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                           t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                           p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.union.phone


mean(union.membs.control$phone.recruit,na.rm=T)

# Peasant Assoc. Members

camp.membs.treat<-camp.membs[camp.membs$flier!="control",]
camp.membs.control<-camp.membs[camp.membs$flier=="control",]

cdata.camp.phone <- ddply(camp.membs.treat, "flier", summarise,
                          N    = sum(!is.na(phone.recruit)),
                          N.control = sum(!is.na(camp.membs.control$phone.recruit)),
                          mean = mean(phone.recruit,na.rm=T),
                          sd.treat   = sd(phone.recruit,na.rm=T),
                          sd.control = sd(camp.membs.control$phone.recruit,na.rm=T),
                          effect = mean(phone.recruit,na.rm=T)-mean(camp.membs.control$phone.recruit,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.camp.phone

mean(camp.membs.control$phone.recruit,na.rm=T)

# Neighborhood Assoc. Members

neigh.membs.treat<-neigh.membs[neigh.membs$flier!="control",]
neigh.membs.control<-neigh.membs[neigh.membs$flier=="control",]

cdata.neigh.phone <- ddply(neigh.membs.treat, "flier", summarise,
                           N    = sum(!is.na(phone.recruit)),
                           N.control = sum(!is.na(neigh.membs.control$phone.recruit)),
                           mean = mean(phone.recruit,na.rm=T),
                           sd.treat   = sd(phone.recruit,na.rm=T),
                           sd.control = sd(neigh.membs.control$phone.recruit,na.rm=T),
                           effect = mean(phone.recruit,na.rm=T)-mean(neigh.membs.control$phone.recruit,na.rm=T),
                           se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                           t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                           p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.neigh.phone

mean(neigh.membs.control$phone.recruit,na.rm=T)

# Business Assoc. Members

bus.membs.treat<-bus.membs[bus.membs$flier!="control",]
bus.membs.control<-bus.membs[bus.membs$flier=="control",]

cdata.bus.phone <- ddply(bus.membs.treat, "flier", summarise,
                         N    = sum(!is.na(phone.recruit)),
                         N.control = sum(!is.na(bus.membs.control$phone.recruit)),
                         mean = mean(phone.recruit,na.rm=T),
                         sd.treat   = sd(phone.recruit,na.rm=T),
                         sd.control = sd(bus.membs.control$phone.recruit,na.rm=T),
                         effect = mean(phone.recruit,na.rm=T)-mean(bus.membs.control$phone.recruit,na.rm=T),
                         se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                         t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                         p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.bus.phone

mean(bus.membs.control$phone.recruit,na.rm=T)

sum(!is.na(union.membs$phone.recruit))
sum(!is.na(camp.membs$phone.recruit))
sum(!is.na(neigh.membs$phone.recruit))
sum(!is.na(bus.membs$phone.recruit))


########## Appendix Table 7: Low-Income vs. High-Income (State-Based Measure) by Membership

lo.inc<-data[data$income2.state=="low",]
lo.inc<-lo.inc[!is.na(lo.inc$income2.state),]

hi.inc<-data[data$income2.state=="high",]
hi.inc<-hi.inc[!is.na(hi.inc$income2.state),]

lo.inc.treat<-lo.inc[lo.inc$flier!="control",]
lo.inc.control<-lo.inc[lo.inc$flier=="control",]

hi.inc.treat<-hi.inc[hi.inc$flier!="control",]
hi.inc.control<-hi.inc[hi.inc$flier=="control",]

lo.inc.memb<-lo.inc[lo.inc$org_mem2==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem2),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem2==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem2),]

hi.inc.memb<-hi.inc[hi.inc$org_mem2==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem2),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem2==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem2),]

# Low-Income Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

aggregate(c(lo.inc.memb$phone.recruit), list(lo.inc.memb$flier), mean,na.rm=T)

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

mean(lo.inc.memb.control$phone.recruit,na.rm=T)

# Low-Income Non-Members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

mean(lo.inc.nomemb.control$phone.recruit,na.rm=T)

# High-Income Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone

mean(hi.inc.memb.control$phone.recruit,na.rm=T)

# High-Income Non-Members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit,na.rm=T)


# N's
sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Appendix Table 8: Low-Education vs. High-Education by Membership

lo.inc<-data[data$ed2=="low",]
lo.inc<-lo.inc[!is.na(lo.inc$ed2),]

hi.inc<-data[data$ed2=="high",]
hi.inc<-hi.inc[!is.na(hi.inc$ed2),]

lo.inc.treat<-lo.inc[lo.inc$flier!="control",]
lo.inc.control<-lo.inc[lo.inc$flier=="control",]

hi.inc.treat<-hi.inc[hi.inc$flier!="control",]
hi.inc.control<-hi.inc[hi.inc$flier=="control",]

lo.inc.memb<-lo.inc[lo.inc$org_mem2==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem2),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem2==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem2),]

hi.inc.memb<-hi.inc[hi.inc$org_mem2==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem2),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem2==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem2),]

# Low-Education Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

aggregate(c(lo.inc.memb$phone.recruit), list(lo.inc.memb$flier), mean,na.rm=T)

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

mean(lo.inc.memb.control$phone.recruit,na.rm=T)

# Low-Education Non-members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

mean(lo.inc.nomemb.control$phone.recruit,na.rm=T)

# High-Education Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone

mean(hi.inc.memb.control$phone.recruit,na.rm=T)

# High-Education Non-Members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit,na.rm=T)

#N's
sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Appendix Table 9: High-Poverty vs. Low-Poverty Section (Based on Occupancy Rate) by Membership

lo.inc<-data[data$occ.rate2=="hi",]
lo.inc<-lo.inc[!is.na(lo.inc$occ.rate2),]

hi.inc<-data[data$occ.rate2=="lo",]
hi.inc<-hi.inc[!is.na(hi.inc$occ.rate2),]

lo.inc.treat<-lo.inc[lo.inc$flier!="control",]
lo.inc.control<-lo.inc[lo.inc$flier=="control",]

hi.inc.treat<-hi.inc[hi.inc$flier!="control",]
hi.inc.control<-hi.inc[hi.inc$flier=="control",]

lo.inc.memb<-lo.inc[lo.inc$org_mem2==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem2),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem2==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem2),]

hi.inc.memb<-hi.inc[hi.inc$org_mem2==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem2),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem2==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem2),]

# High-Poverty Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

aggregate(c(lo.inc.memb$phone.recruit), list(lo.inc.memb$flier), mean,na.rm=T)

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

mean(lo.inc.memb.control$phone.recruit,na.rm=T)

# High-Poverty Non-members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

mean(lo.inc.nomemb.control$phone.recruit,na.rm=T)

# Low-Poverty Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone

mean(hi.inc.memb.control$phone.recruit,na.rm=T)

# Low-Poverty Non-Members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit,na.rm=T)

# N's
sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Appendix Table 10: Rural vs. Urban Municipality (<50K Population) by Membership

lo.inc<-data[data$rural50K=="1",]
lo.inc<-lo.inc[!is.na(lo.inc$rural50K),]

hi.inc<-data[data$rural50K=="0",]
hi.inc<-hi.inc[!is.na(hi.inc$rural50K),]

lo.inc.treat<-lo.inc[lo.inc$flier!="control",]
lo.inc.control<-lo.inc[lo.inc$flier=="control",]

hi.inc.treat<-hi.inc[hi.inc$flier!="control",]
hi.inc.control<-hi.inc[hi.inc$flier=="control",]

lo.inc.memb<-lo.inc[lo.inc$org_mem2==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem2),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem2==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem2),]

hi.inc.memb<-hi.inc[hi.inc$org_mem2==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem2),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem2==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem2),]

# Rural Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

aggregate(c(lo.inc.memb$phone.recruit), list(lo.inc.memb$flier), mean,na.rm=T)

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

mean(lo.inc.memb.control$phone.recruit,na.rm=T)

# Rural Non-members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

mean(lo.inc.nomemb.control$phone.recruit,na.rm=T)

# Urban Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone

mean(hi.inc.memb.control$phone.recruit,na.rm=T)

# Urban Non-members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit,na.rm=T)


#N
sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Appendix Figure 2: Class and Organization Membership Using Ordinal Measure of Income

dat.control<-data[data$flier=="control",]
dat.gestion<-data[data$flier=="gestion",]
dat.public<-data[data$flier=="public",]
dat.services<-data[data$flier=="services",]
dat.pressure<-data[data$flier=="pressure",]

dat.gestion$org_mem2<-as.factor(dat.gestion$org_mem2)
dat.gestion<-dat.gestion[!is.na(dat.gestion$income2),]
dat.gestion<-dat.gestion[!is.na(dat.gestion$org_mem2),]

dat.public$org_mem2<-as.factor(dat.public$org_mem2)
dat.public<-dat.public[!is.na(dat.public$income2),]
dat.public<-dat.public[!is.na(dat.public$org_mem2),]

dat.services$org_mem2<-as.factor(dat.services$org_mem2)
dat.services<-dat.services[!is.na(dat.services$income2),]
dat.services<-dat.services[!is.na(dat.services$org_mem2),]

dat.pressure$org_mem2<-as.factor(dat.pressure$org_mem2)
dat.pressure<-dat.pressure[!is.na(dat.pressure$income2),]
dat.pressure<-dat.pressure[!is.na(dat.pressure$org_mem2),]
dat.pressure<-dat.pressure[!is.na(dat.pressure$phone.recruit),]

dat.control$org_mem2<-as.factor(dat.control$org_mem2)
dat.control<-dat.control[!is.na(dat.control$income2),]
dat.control<-dat.control[!is.na(dat.control$org_mem2),]



a<-ggplot(data=dat.control,aes(y=phone.recruit,x=income)) + geom_smooth(aes(linetype=org_mem2,color=org_mem2),method="lm")+ geom_rug(sides="b",position="jitter") + ylab(label="Response Rate (Control)") +xlab(label="Income (ordinal measure)")+theme (axis.title=element_text(size=20), legend.position="none") + scale_colour_manual(values = c("black", "gray47")) + ylim(0, 1)

b<-ggplot(data=dat.gestion,aes(y=phone.recruit,x=income)) + geom_smooth(aes(linetype=org_mem2,color=org_mem2),method="lm")+ geom_rug(sides="b",position="jitter") + ylab(label="Response Rate (Subsidies)") +xlab(label="Income (ordinal measure)")+theme (axis.title=element_text(size=20), legend.position="none") + scale_colour_manual(values = c("black", "gray47")) + ylim(0, 1)

c<-ggplot(data=dat.public,aes(y=phone.recruit,x=income)) + geom_smooth(aes(linetype=org_mem2,color=org_mem2),method="lm")+ geom_rug(sides="b",position="jitter") + ylab(label="Response Rate (Public)") +xlab(label="Income (ordinal measure)")+theme (axis.title=element_text(size=20), legend.position="none") + scale_colour_manual(values = c("black", "gray47")) + ylim(0, 1)

d<-ggplot(data=dat.services,aes(y=phone.recruit,x=income)) + geom_smooth(aes(linetype=org_mem2,color=org_mem2),method="lm")+ geom_rug(sides="b",position="jitter") + ylab(label="Response Rate (Services)") +xlab(label="Income (ordinal measure)")+theme (axis.title=element_text(size=20), legend.position="none") + scale_colour_manual(values = c("black", "gray47")) + ylim(0, 1)

dat.pressure$Organization.Member<-NA
dat.pressure$Organization.Member[dat.pressure$org_mem2==1]<-"Member"
dat.pressure$Organization.Member[dat.pressure$org_mem2==0]<-"Non-Member"

dat.pressure$Organization.Member <- relevel(as.factor(dat.pressure$Organization.Member), "Non-Member")


e<-ggplot(data=dat.pressure,aes(y=phone.recruit,x=income)) + geom_smooth(aes(linetype=Organization.Member,color=Organization.Member),method="lm", se=T)+ geom_rug(sides="b",position="jitter") + ylab(label="Response Rate (Peer Esteem)") +xlab(label="Income (ordinal measure)")+theme(axis.title=element_text(size=20), legend.position=c(1.5, .5), legend.text=element_text(size=20),legend.title=element_blank()) + scale_colour_manual(values = c("black", "gray47")) + ylim(0, 1) 

pdf(file="AppenFig2.pdf",width=10,height=12)

plot_grid(a,b,c,d,e,align="hv",axis="b",nrow=3)

dev.off()


########## Appendix Table 11: Overall Findings, Chiapas

data.chiapas<-data[data$estado=="Chiapas",]

data.treat<-data.chiapas[data.chiapas$flier!="control",]
data.control<-data.chiapas[data.chiapas$flier=="control",]

# Declared Interest

cdata <- ddply(data.treat, "flier", summarise,
               N    = length(recruit.dum),
               N.control = sum(!is.na(data.control$recruit.dum)),
               mean = mean(recruit.dum,na.rm=T),
               sd.treat   = sd(recruit.dum,na.rm=T),
               sd.control = sd(data.control$recruit.dum,na.rm=T),
               effect = mean(recruit.dum,na.rm=T)-mean(data.control$recruit.dum,na.rm=T),
               se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / sum(!is.na(data.control$recruit.dum)))),
               t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
               p.value=pt(t.value,length(recruit.dum)+sum(!is.na(data.control$recruit.dum))-2,lower.tail=F)
)
cdata

mean(data.control$recruit.dum,na.rm=T)

# Behavioral Measure

cdata.phone <- ddply(data.treat, "flier", summarise,
                     N    = sum(!is.na(phone.recruit)),
                     N.control = sum(!is.na(data.control$phone.recruit)),
                     mean = mean(phone.recruit,na.rm=T),
                     sd.treat   = sd(phone.recruit,na.rm=T),
                     sd.control = sd(data.control$phone.recruit,na.rm=T),
                     effect = mean(phone.recruit,na.rm=T)-mean(data.control$phone.recruit,na.rm=T),
                     se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / sum(!is.na(data.control$phone.recruit)))),
                     t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                     p.value=pt(t.value,length(phone.recruit)+N.control-2,lower.tail=F)
)
cdata.phone

mean(data.control$phone.recruit,na.rm=T)

sum(!is.na(data.chiapas$recruit.dum))


########## Appendix Table 12: Overall Findings, Mexico City

data.df<-data[data$estado=="DF",]

data.treat<-data.df[data.df$flier!="control",]
data.control<-data.df[data.df$flier=="control",]

# Declared Interest

cdata <- ddply(data.treat, "flier", summarise,
               N    = length(recruit.dum),
               N.control = sum(!is.na(data.control$recruit.dum)),
               mean = mean(recruit.dum,na.rm=T),
               sd.treat   = sd(recruit.dum,na.rm=T),
               sd.control = sd(data.control$recruit.dum,na.rm=T),
               effect = mean(recruit.dum,na.rm=T)-mean(data.control$recruit.dum,na.rm=T),
               se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / sum(!is.na(data.control$recruit.dum)))),
               t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
               p.value=pt(t.value,length(recruit.dum)+sum(!is.na(data.control$recruit.dum))-2,lower.tail=F)
)
cdata

mean(data.control$recruit.dum,na.rm=T)

# Behavioral Measure

cdata.phone <- ddply(data.treat, "flier", summarise,
                     N    = sum(!is.na(phone.recruit)),
                     N.control = sum(!is.na(data.control$phone.recruit)),
                     mean = mean(phone.recruit,na.rm=T),
                     sd.treat   = sd(phone.recruit,na.rm=T),
                     sd.control = sd(data.control$phone.recruit,na.rm=T),
                     effect = mean(phone.recruit,na.rm=T)-mean(data.control$phone.recruit,na.rm=T),
                     se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / sum(!is.na(data.control$phone.recruit)))),
                     t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                     p.value=pt(t.value,length(phone.recruit)+N.control-2,lower.tail=F)
)
cdata.phone

mean(data.control$phone.recruit,na.rm=T)

sum(!is.na(data.df$recruit.dum))


########## Appendix Table 13: Low-Income vs. High-Income, Chiapas

lo.inc<-data.chiapas[data.chiapas$income2.state=="low",]
lo.inc<-lo.inc[!is.na(lo.inc$income2.state),]

hi.inc<-data.chiapas[data.chiapas$income2.state=="high",]
hi.inc<-hi.inc[!is.na(hi.inc$income2.state),]

lo.inc.treat<-lo.inc[lo.inc$flier!="control",]
lo.inc.control<-lo.inc[lo.inc$flier=="control",]

hi.inc.treat<-hi.inc[hi.inc$flier!="control",]
hi.inc.control<-hi.inc[hi.inc$flier=="control",]

# Declared, Low-Income

cdata.lo.inc <- ddply(lo.inc.treat, "flier", summarise,
                      N    = length(recruit.dum),
                      N.control = sum(!is.na(lo.inc.control$recruit.dum)),
                      mean = mean(recruit.dum,na.rm=T),
                      sd.treat   = sd(recruit.dum,na.rm=T),
                      sd.control = sd(lo.inc.control$recruit.dum,na.rm=T),
                      effect = mean(recruit.dum,na.rm=T)-mean(lo.inc.control$recruit.dum,na.rm=T),
                      se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                      t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                      p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.lo.inc

mean(lo.inc.control$recruit.dum,na.rm=T)

# Declared High-Income

cdata.hi.inc <- ddply(hi.inc.treat, "flier", summarise,
                      N    = length(recruit.dum),
                      N.control = sum(!is.na(hi.inc.control$recruit.dum)),
                      mean = mean(recruit.dum,na.rm=T),
                      sd.treat   = sd(recruit.dum,na.rm=T),
                      sd.control = sd(hi.inc.control$recruit.dum,na.rm=T),
                      effect = mean(recruit.dum,na.rm=T)-mean(hi.inc.control$recruit.dum,na.rm=T),
                      se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                      t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                      p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hi.inc

mean(hi.inc.control$recruit.dum,na.rm=T)

# Behavioral, Low-Income

cdata.lo.inc.phone <- ddply(lo.inc.treat, "flier", summarise,
                            N    = length(phone.recruit),
                            N.control = sum(!is.na(lo.inc.control$phone.recruit)),
                            mean = mean(phone.recruit,na.rm=T),
                            sd.treat   = sd(phone.recruit,na.rm=T),
                            sd.control = sd(lo.inc.control$phone.recruit,na.rm=T),
                            effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.control$phone.recruit,na.rm=T),
                            se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                            t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                            p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.lo.inc.phone

mean(lo.inc.control$phone.recruit,na.rm=T)

# Behavioral, High-Income

cdata.hi.inc.phone <- ddply(hi.inc.treat, "flier", summarise,
                            N    = length(phone.recruit),
                            N.control = sum(!is.na(hi.inc.control$phone.recruit)),
                            mean = mean(phone.recruit,na.rm=T),
                            sd.treat   = sd(phone.recruit,na.rm=T),
                            sd.control = sd(hi.inc.control$phone.recruit,na.rm=T),
                            effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.control$phone.recruit,na.rm=T),
                            se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                            t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                            p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hi.inc.phone

mean(hi.inc.control$phone.recruit,na.rm=T)


########## Appendix Table 14: Low-Income vs. High-Income, Mexico City

lo.inc<-data.df[data.df$income2.state=="low",]
lo.inc<-lo.inc[!is.na(lo.inc$income2.state),]

hi.inc<-data.df[data.df$income2.state=="high",]
hi.inc<-hi.inc[!is.na(hi.inc$income2.state),]

lo.inc.treat<-lo.inc[lo.inc$flier!="control",]
lo.inc.control<-lo.inc[lo.inc$flier=="control",]

hi.inc.treat<-hi.inc[hi.inc$flier!="control",]
hi.inc.control<-hi.inc[hi.inc$flier=="control",]

# Declared, Low-Income

cdata.lo.inc <- ddply(lo.inc.treat, "flier", summarise,
                      N    = length(recruit.dum),
                      N.control = sum(!is.na(lo.inc.control$recruit.dum)),
                      mean = mean(recruit.dum,na.rm=T),
                      sd.treat   = sd(recruit.dum,na.rm=T),
                      sd.control = sd(lo.inc.control$recruit.dum,na.rm=T),
                      effect = mean(recruit.dum,na.rm=T)-mean(lo.inc.control$recruit.dum,na.rm=T),
                      se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                      t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                      p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.lo.inc

mean(lo.inc.control$recruit.dum,na.rm=T)

# Declared, High-Income

cdata.hi.inc <- ddply(hi.inc.treat, "flier", summarise,
                      N    = length(recruit.dum),
                      N.control = sum(!is.na(hi.inc.control$recruit.dum)),
                      mean = mean(recruit.dum,na.rm=T),
                      sd.treat   = sd(recruit.dum,na.rm=T),
                      sd.control = sd(hi.inc.control$recruit.dum,na.rm=T),
                      effect = mean(recruit.dum,na.rm=T)-mean(hi.inc.control$recruit.dum,na.rm=T),
                      se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                      t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                      p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hi.inc

mean(hi.inc.control$recruit.dum,na.rm=T)

# Behavioral, Low-Income

cdata.lo.inc.phone <- ddply(lo.inc.treat, "flier", summarise,
                            N    = length(phone.recruit),
                            N.control = sum(!is.na(lo.inc.control$phone.recruit)),
                            mean = mean(phone.recruit,na.rm=T),
                            sd.treat   = sd(phone.recruit,na.rm=T),
                            sd.control = sd(lo.inc.control$phone.recruit,na.rm=T),
                            effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.control$phone.recruit,na.rm=T),
                            se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                            t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                            p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.lo.inc.phone

mean(lo.inc.control$phone.recruit,na.rm=T)

# Behavioral, High-Income

cdata.hi.inc.phone <- ddply(hi.inc.treat, "flier", summarise,
                            N    = length(phone.recruit),
                            N.control = sum(!is.na(hi.inc.control$phone.recruit)),
                            mean = mean(phone.recruit,na.rm=T),
                            sd.treat   = sd(phone.recruit,na.rm=T),
                            sd.control = sd(hi.inc.control$phone.recruit,na.rm=T),
                            effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.control$phone.recruit,na.rm=T),
                            se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                            t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                            p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hi.inc.phone

mean(hi.inc.control$phone.recruit,na.rm=T)


########## Appendix Table 15: Members vs. Non-Members, Chiapas

org.membs<-data.chiapas[data.chiapas$org_mem2==1&!is.na(data.chiapas$org_mem2),]
non.membs<-data.chiapas[data.chiapas$org_mem2==0&!is.na(data.chiapas$org_mem2),]

org.membs.treat<-org.membs[org.membs$flier!="control"&!is.na(org.membs$flier),]
org.membs.control<-org.membs[org.membs$flier=="control",]

non.membs.treat<-non.membs[non.membs$flier!="control"&!is.na(non.membs$flier),]
non.membs.control<-non.membs[non.membs$flier=="control",]

# Declared, Members

cdata.memb <- ddply(org.membs.treat, "flier", summarise,
                    N    = length(recruit.dum),
                    N.control = sum(!is.na(org.membs.control$recruit.dum)),
                    mean = mean(recruit.dum,na.rm=T),
                    sd.treat   = sd(recruit.dum,na.rm=T),
                    sd.control = sd(org.membs.control$recruit.dum,na.rm=T),
                    effect = mean(recruit.dum,na.rm=T)-mean(org.membs.control$recruit.dum,na.rm=T),
                    se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                    t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                    p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb

mean(org.membs.control$recruit.dum,na.rm=T)

# Declared, Non-Members

cdata.nonmemb <- ddply(non.membs.treat, "flier", summarise,
                       N    = length(recruit.dum),
                       N.control = sum(!is.na(non.membs.control$recruit.dum)),
                       mean = mean(recruit.dum,na.rm=T),
                       sd.treat   = sd(recruit.dum,na.rm=T),
                       sd.control = sd(org.membs.control$recruit.dum,na.rm=T),
                       effect = mean(recruit.dum,na.rm=T)-mean(non.membs.control$recruit.dum,na.rm=T),
                       se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                       t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                       p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb

mean(non.membs.control$recruit.dum,na.rm=T)

# Behavioral, Members

cdata.memb.phone <- ddply(org.membs.treat, "flier", summarise,
                          N    = sum(!is.na(phone.recruit)),
                          N.control = sum(!is.na(org.membs.control$phone.recruit)),
                          mean = mean(phone.recruit,na.rm=T),
                          sd.treat   = sd(phone.recruit,na.rm=T),
                          sd.control = sd(org.membs.control$phone.recruit,na.rm=T),
                          effect = mean(phone.recruit,na.rm=T)-mean(org.membs.control$phone.recruit,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb.phone

mean(org.membs.control$phone.recruit,na.rm=T)


# Behavioral, Non-Members

cdata.nonmemb.phone <- ddply(non.membs.treat, "flier", summarise,
                             N    = sum(!is.na(phone.recruit)),
                             N.control = sum(!is.na(non.membs.control$phone.recruit)),
                             mean = mean(phone.recruit,na.rm=T),
                             sd.treat   = sd(phone.recruit,na.rm=T),
                             sd.control = sd(non.membs.control$phone.recruit,na.rm=T),
                             effect = mean(phone.recruit,na.rm=T)-mean(non.membs.control$phone.recruit,na.rm=T),
                             se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                             t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                             p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb.phone

mean(non.membs.control$phone.recruit,na.rm=T)


########## Appendix Table 16: Members vs. Non-Members, Mexico City

org.membs<-data.df[data.df$org_mem2==1&!is.na(data.df$org_mem2),]
non.membs<-data.df[data.df$org_mem2==0&!is.na(data.df$org_mem2),]

org.membs.treat<-org.membs[org.membs$flier!="control"&!is.na(org.membs$flier),]
org.membs.control<-org.membs[org.membs$flier=="control",]

non.membs.treat<-non.membs[non.membs$flier!="control"&!is.na(non.membs$flier),]
non.membs.control<-non.membs[non.membs$flier=="control",]

# Declared, Members

cdata.memb <- ddply(org.membs.treat, "flier", summarise,
                    N    = length(recruit.dum),
                    N.control = sum(!is.na(org.membs.control$recruit.dum)),
                    mean = mean(recruit.dum,na.rm=T),
                    sd.treat   = sd(recruit.dum,na.rm=T),
                    sd.control = sd(org.membs.control$recruit.dum,na.rm=T),
                    effect = mean(recruit.dum,na.rm=T)-mean(org.membs.control$recruit.dum,na.rm=T),
                    se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                    t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                    p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb

mean(org.membs.control$recruit.dum,na.rm=T)

# Declared, Non-Members

cdata.nonmemb <- ddply(non.membs.treat, "flier", summarise,
                       N    = length(recruit.dum),
                       N.control = sum(!is.na(non.membs.control$recruit.dum)),
                       mean = mean(recruit.dum,na.rm=T),
                       sd.treat   = sd(recruit.dum,na.rm=T),
                       sd.control = sd(org.membs.control$recruit.dum,na.rm=T),
                       effect = mean(recruit.dum,na.rm=T)-mean(non.membs.control$recruit.dum,na.rm=T),
                       se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                       t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                       p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb

mean(non.membs.control$recruit.dum,na.rm=T)

# Behavioral, Members

cdata.memb.phone <- ddply(org.membs.treat, "flier", summarise,
                          N    = sum(!is.na(phone.recruit)),
                          N.control = sum(!is.na(org.membs.control$phone.recruit)),
                          mean = mean(phone.recruit,na.rm=T),
                          sd.treat   = sd(phone.recruit,na.rm=T),
                          sd.control = sd(org.membs.control$phone.recruit,na.rm=T),
                          effect = mean(phone.recruit,na.rm=T)-mean(org.membs.control$phone.recruit,na.rm=T),
                          se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                          t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                          p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.memb.phone

mean(org.membs.control$phone.recruit,na.rm=T)


# Behavioral, Non-Members

cdata.nonmemb.phone <- ddply(non.membs.treat, "flier", summarise,
                             N    = sum(!is.na(phone.recruit)),
                             N.control = sum(!is.na(non.membs.control$phone.recruit)),
                             mean = mean(phone.recruit,na.rm=T),
                             sd.treat   = sd(phone.recruit,na.rm=T),
                             sd.control = sd(non.membs.control$phone.recruit,na.rm=T),
                             effect = mean(phone.recruit,na.rm=T)-mean(non.membs.control$phone.recruit,na.rm=T),
                             se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                             t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                             p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.nonmemb.phone

mean(non.membs.control$phone.recruit,na.rm=T)


########## Appendix Table 17: Low-Income vs. High-Income by Membership, Chiapas

lo.inc<-data.chiapas[data.chiapas$income2.state=="low",]
lo.inc<-lo.inc[!is.na(lo.inc$income2.state),]

hi.inc<-data.chiapas[data.chiapas$income2.state=="high",]
hi.inc<-hi.inc[!is.na(hi.inc$income2.state),]

lo.inc.memb<-lo.inc[lo.inc$org_mem2==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem2),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem2==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem2),]

hi.inc.memb<-hi.inc[hi.inc$org_mem2==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem2),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem2==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem2),]

# Low-Income Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

mean(lo.inc.memb.control$phone.recruit,na.rm=T)

# Low-Income Non-members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

mean(lo.inc.nomemb.control$phone.recruit,na.rm=T)

# High-Income Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone

mean(hi.inc.memb.control$phone.recruit,na.rm=T)

# High-Income Non-Members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit,na.rm=T)

sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Appendix Table 18: Low-Income vs. High-Income by Membership, Mexico City

lo.inc<-data.df[data.df$income2.state=="low",]
lo.inc<-lo.inc[!is.na(lo.inc$income2.state),]

hi.inc<-data.df[data.df$income2.state=="high",]
hi.inc<-hi.inc[!is.na(hi.inc$income2.state),]

lo.inc.memb<-lo.inc[lo.inc$org_mem2==1,]
lo.inc.memb<-lo.inc.memb[!is.na(lo.inc.memb$org_mem2),]

lo.inc.nomemb<-lo.inc[lo.inc$org_mem2==0,]
lo.inc.nomemb<-lo.inc.nomemb[!is.na(lo.inc.nomemb$org_mem2),]

hi.inc.memb<-hi.inc[hi.inc$org_mem2==1,]
hi.inc.memb<-hi.inc.memb[!is.na(hi.inc.memb$org_mem2),]

hi.inc.nomemb<-hi.inc[hi.inc$org_mem2==0,]
hi.inc.nomemb<-hi.inc.nomemb[!is.na(hi.inc.nomemb$org_mem2),]

# Low-Income Members

lo.inc.memb.treat<-lo.inc.memb[lo.inc.memb$flier!="control"&!is.na(lo.inc.memb$flier),]
lo.inc.memb.control<-lo.inc.memb[lo.inc.memb$flier=="control",]

cdata.loinc.memb.phone <- ddply(lo.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(lo.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(lo.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.memb.phone

mean(lo.inc.memb.control$phone.recruit,na.rm=T)

# Low-Income Non-members

lo.inc.nomemb.treat<-lo.inc.nomemb[lo.inc.nomemb$flier!="control"&!is.na(lo.inc.nomemb$flier),]
lo.inc.nomemb.control<-lo.inc.nomemb[lo.inc.nomemb$flier=="control",]

cdata.loinc.nomemb.phone <- ddply(lo.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(lo.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(lo.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.loinc.nomemb.phone

mean(lo.inc.nomemb.control$phone.recruit,na.rm=T)

# High-Income Members

hi.inc.memb.treat<-hi.inc.memb[hi.inc.memb$flier!="control"&!is.na(hi.inc.memb$flier),]
hi.inc.memb.control<-hi.inc.memb[hi.inc.memb$flier=="control",]

cdata.hiinc.memb.phone <- ddply(hi.inc.memb.treat, "flier", summarise,
                                N    = sum(!is.na(phone.recruit)),
                                N.control = sum(!is.na(hi.inc.memb.control$phone.recruit)),
                                mean = mean(phone.recruit,na.rm=T),
                                sd.treat   = sd(phone.recruit,na.rm=T),
                                sd.control = sd(hi.inc.memb.control$phone.recruit,na.rm=T),
                                effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.memb.control$phone.recruit,na.rm=T),
                                se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.memb.phone

mean(hi.inc.memb.control$phone.recruit,na.rm=T)

# High-Income Non-Members

hi.inc.nomemb.treat<-hi.inc.nomemb[hi.inc.nomemb$flier!="control"&!is.na(hi.inc.nomemb$flier),]
hi.inc.nomemb.control<-hi.inc.nomemb[hi.inc.memb$flier=="control",]

cdata.hiinc.nomemb.phone <- ddply(hi.inc.nomemb.treat, "flier", summarise,
                                  N    = sum(!is.na(phone.recruit)),
                                  N.control = sum(!is.na(hi.inc.nomemb.control$phone.recruit)),
                                  mean = mean(phone.recruit,na.rm=T),
                                  sd.treat   = sd(phone.recruit,na.rm=T),
                                  sd.control = sd(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  effect = mean(phone.recruit,na.rm=T)-mean(hi.inc.nomemb.control$phone.recruit,na.rm=T),
                                  se.effect   = sqrt((sd.treat^2 / N)+(sd.control^2 / N.control)),
                                  t.value = effect/(sqrt((sd.treat^2/N)+sd.control^2/N.control)),
                                  p.value=pt(t.value,N+N.control-2,lower.tail=F)
)
cdata.hiinc.nomemb.phone

mean(hi.inc.nomemb.control$phone.recruit,na.rm=T)

sum(!is.na(lo.inc.memb$phone.recruit))
sum(!is.na(lo.inc.nomemb$phone.recruit))
sum(!is.na(hi.inc.memb$phone.recruit))
sum(!is.na(hi.inc.nomemb$phone.recruit))


########## Appendix Table 19: Comparing Treatment Groups on Covariates

# Mexico City
data$df.dat[data$estado=="DF"]<-1
data$df.dat[data$estado=="Chiapas"]<-0

aggregate(c(data$df.dat), list(data$flier), mean,na.rm=T)

t.test(data$df.dat[data$flier=="gestion"],data$df.dat[data$flier=="public"],conf.level=.90,alternative="two.sided")

# Female
aggregate(c(data$female), list(data$flier), mean,na.rm=T)

t.test(data$female[data$flier=="gestion"],data$female[data$flier=="public"],conf.level=.90,alternative="two.sided")

# Age
aggregate(c(data$A1), list(data$flier), mean,na.rm=T)

t.test(data$A1[data$flier=="control"],data$A1[data$flier=="pressure"],conf.level=.95,alternative="two.sided")

# Rural
aggregate(c(data$rural50K), list(data$flier), mean,na.rm=T)

t.test(data$rural50K[data$flier=="control"],data$rural50K[data$flier=="services"],conf.level=.90,alternative="two.sided")

# Income
aggregate(c(data$income), list(data$flier), mean,na.rm=T)

t.test(data$income[data$flier=="pressure"],data$income[data$flier=="services"],conf.level=.95,alternative="two.sided")

# Education
aggregate(c(data$ed), list(data$flier), mean,na.rm=T)

t.test(data$ed[data$flier=="public"],data$ed[data$flier=="gestion"],conf.level=.90,alternative="two.sided")

# Informal Sector
aggregate(c(data$employed.informal), list(data$flier), mean,na.rm=T)

t.test(data$employed.informal[data$flier=="public"],data$employed.informal[data$flier=="control"],conf.level=.90,alternative="two.sided")

# Org. Member
aggregate(c(data$org_mem2), list(data$flier), mean,na.rm=T)

t.test(data$org_mem2[data$flier=="public"],data$manifest[data$flier=="services"],conf.level=.90,alternative="two.sided")

# Protest/Rally Participation
aggregate(c(data$manifest), list(data$flier), mean,na.rm=T)

t.test(data$manifest[data$flier=="gestion"],data$manifest[data$flier=="public"],conf.level=.90,alternative="two.sided")

# Voted in 2015
aggregate(c(data$voted.2015), list(data$flier), mean,na.rm=T)

t.test(data$voted.2015[data$flier=="control"],data$voted.2015[data$flier=="pressure"],conf.level=.90,alternative="two.sided")

# Partisan
aggregate(c(data$partisan), list(data$flier), mean,na.rm=T)

t.test(data$partisan[data$flier=="gestion"],data$partisan[data$flier=="services"],conf.level=.90,alternative="two.sided")

# PRI Partisan
aggregate(c(data$PRI.dum), list(data$flier), mean,na.rm=T)

t.test(data$PRI.dum[data$flier=="gestion"],data$PRI.dum[data$flier=="services"],conf.level=.90,alternative="two.sided")

# Beneficiary
aggregate(c(data$ben.dum), list(data$flier), mean,na.rm=T)

t.test(data$ben.dum[data$flier=="control"],data$ben.dum[data$flier=="public"],conf.level=.90,alternative="two.sided")

# Clientelism
aggregate(c(data$client), list(data$flier), mean,na.rm=T)

t.test(data$client[data$flier=="control"],data$client[data$flier=="public"],conf.level=.90,alternative="two.sided")

